@@ -13,7 +13,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from debtcollector import removals
 import flask
 import webob.dec
 from oslo_config import cfg
@@ -21,7 +20,7 @@ import oslo_messaging as messaging
 from oslo_log import log as logging
 from oslo_middleware import base
 from oslo_middleware import request_id
-from oslo_serialization import jsonutils as json
+from oslo_serialization import jsonutils
 from oslo_utils import strutils
 
 from designate import exceptions
@@ -52,42 +51,45 @@ def auth_pipeline_factory(loader, global_conf, **local_conf):
 
 
 class ContextMiddleware(base.Middleware):
-    def _extract_sudo(self, ctxt, request):
-        if request.headers.get('X-Auth-Sudo-Tenant-ID') or \
-                request.headers.get('X-Auth-Sudo-Project-ID'):
-            ctxt.sudo(
-                request.headers.get('X-Auth-Sudo-Tenant-ID') or
-                request.headers.get('X-Auth-Sudo-Project-ID')
-            )
+    @staticmethod
+    def _extract_sudo(ctxt, request):
+        if request.headers.get('X-Auth-Sudo-Project-ID'):
+            ctxt.sudo(request.headers.get('X-Auth-Sudo-Project-ID'))
+        elif request.headers.get('X-Auth-Sudo-Tenant-ID'):
+            ctxt.sudo(request.headers.get('X-Auth-Sudo-Tenant-ID'))
 
-    def _extract_all_projects(self, ctxt, request):
+    @staticmethod
+    def _extract_all_projects(ctxt, request):
         ctxt.all_tenants = False
         if request.headers.get('X-Auth-All-Projects'):
             value = request.headers.get('X-Auth-All-Projects')
             ctxt.all_tenants = strutils.bool_from_string(value)
 
-        for i in ('all_projects', 'all_tenants', ):
-            if i in request.GET:
-                value = request.GET.pop(i)
+        for name in ('all_projects', 'all_tenants', ):
+            if name in request.GET:
+                value = request.GET.pop(name)
                 ctxt.all_tenants = strutils.bool_from_string(value)
 
-    def _extract_dns_hide_counts(self, ctxt, request):
+    @staticmethod
+    def _extract_dns_hide_counts(ctxt, request):
         ctxt.hide_counts = False
         value = request.headers.get('OpenStack-DNS-Hide-Counts')
         if value:
             ctxt.hide_counts = strutils.bool_from_string(value)
 
-    def _extract_edit_managed_records(self, ctxt, request):
+    @staticmethod
+    def _extract_edit_managed_records(ctxt, request):
         ctxt.edit_managed_records = False
         if 'edit_managed_records' in request.GET:
             value = request.GET.pop('edit_managed_records')
             ctxt.edit_managed_records = strutils.bool_from_string(value)
         elif request.headers.get('X-Designate-Edit-Managed-Records'):
-            ctxt.edit_managed_records = \
-                strutils.bool_from_string(
-                    request.headers.get('X-Designate-Edit-Managed-Records'))
+            ctxt.edit_managed_records = strutils.bool_from_string(
+                request.headers.get('X-Designate-Edit-Managed-Records')
+            )
 
-    def _extract_client_addr(self, ctxt, request):
+    @staticmethod
+    def _extract_client_addr(ctxt, request):
         if hasattr(request, 'client_addr'):
             ctxt.client_addr = request.client_addr
 
@@ -118,7 +120,7 @@ class KeystoneContextMiddleware(ContextMiddleware):
         headers = request.headers
 
         try:
-            if headers['X-Identity-Status'] is 'Invalid':
+            if headers['X-Identity-Status'] == 'Invalid':
                 # TODO(graham) fix the return to use non-flask resources
                 return flask.Response(status=401)
         except KeyError:
@@ -129,10 +131,9 @@ class KeystoneContextMiddleware(ContextMiddleware):
         if tenant_id is None:
             return flask.Response(status=401)
 
+        catalog = None
         if headers.get('X-Service-Catalog'):
-            catalog = json.loads(headers.get('X-Service-Catalog'))
-        else:
-            catalog = None
+            catalog = jsonutils.loads(headers.get('X-Service-Catalog'))
 
         roles = headers.get('X-Roles').split(',')
 
@@ -140,10 +141,11 @@ class KeystoneContextMiddleware(ContextMiddleware):
             self.make_context(
                 request,
                 auth_token=headers.get('X-Auth-Token'),
-                user=headers.get('X-User-ID'),
-                tenant=tenant_id,
+                user_id=headers.get('X-User-ID'),
+                project_id=tenant_id,
                 roles=roles,
-                service_catalog=catalog)
+                service_catalog=catalog
+            )
         except exceptions.Forbidden:
             return flask.Response(status=403)
 
@@ -159,9 +161,9 @@ class NoAuthContextMiddleware(ContextMiddleware):
 
         self.make_context(
             request,
-            auth_token=headers.get('X-Auth-Token', None),
-            user=headers.get('X-Auth-User-ID', 'noauth-user'),
-            tenant=headers.get('X-Auth-Project-ID', 'noauth-project'),
+            auth_token=headers.get('X-Auth-Token'),
+            user_id=headers.get('X-Auth-User-ID', 'noauth-user'),
+            project_id=headers.get('X-Auth-Project-ID', 'noauth-project'),
             roles=headers.get('X-Roles', 'admin').split(',')
         )
 
@@ -184,9 +186,10 @@ class TestContextMiddleware(ContextMiddleware):
 
         self.make_context(
             request,
-            user=headers.get('X-Test-User-ID', self.default_user_id),
-            tenant=headers.get('X-Test-Tenant-ID', self.default_tenant_id),
-            all_tenants=all_tenants)
+            user_id=headers.get('X-Test-User-ID', self.default_user_id),
+            project_id=headers.get('X-Test-Tenant-ID', self.default_tenant_id),
+            all_tenants=all_tenants
+        )
 
 
 class MaintenanceMiddleware(base.Middleware):
@@ -205,8 +208,8 @@ class MaintenanceMiddleware(base.Middleware):
             return None
 
         # If the caller has the bypass role, let them through
-        if ('context' in request.environ
-                and self.role in request.environ['context'].roles):
+        if ('context' in request.environ and
+                self.role in request.environ['context'].roles):
             LOG.warning('Request authorized to bypass maintenance mode')
             return None
 
@@ -233,7 +236,7 @@ class FaultWrapperMiddleware(base.Middleware):
     def __call__(self, request):
         try:
             return request.get_response(self.application)
-        except exceptions.Base as e:
+        except exceptions.DesignateException as e:
             # Handle Designate Exceptions
             status = e.error_code if hasattr(e, 'error_code') else 500
 
@@ -301,14 +304,14 @@ class FaultWrapperMiddleware(base.Middleware):
             LOG.error('Missing context in request, please check.')
 
         return flask.Response(status=status, headers=headers,
-                              response=json.dumps(response))
+                              response=jsonutils.dump_as_bytes(response))
 
 
-class ValidationErrorMiddleware(base.Middleware):
+class APIv2ValidationErrorMiddleware(base.Middleware):
 
     def __init__(self, application):
-        super(ValidationErrorMiddleware, self).__init__(application)
-
+        super(APIv2ValidationErrorMiddleware, self).__init__(application)
+        self.api_version = 'API_v2'
         LOG.info('Starting designate validation middleware')
 
     @webob.dec.wsgify
@@ -322,7 +325,6 @@ class ValidationErrorMiddleware(base.Middleware):
             return self._handle_errors(request, e)
 
     def _handle_errors(self, request, exception):
-
         response = {}
 
         headers = [
@@ -330,14 +332,13 @@ class ValidationErrorMiddleware(base.Middleware):
         ]
 
         rendered_errors = DesignateAdapter.render(
-            self.api_version, exception.errors, failed_object=exception.object)
+            self.api_version, exception.errors, failed_object=exception.object
+        )
 
         url = getattr(request, 'url', None)
 
         response['code'] = exception.error_code
-
         response['type'] = exception.error_type or 'unknown'
-
         response['errors'] = rendered_errors
 
         # Return the new response
@@ -352,35 +353,4 @@ class ValidationErrorMiddleware(base.Middleware):
             LOG.error('Missing context in request, please check.')
 
         return flask.Response(status=exception.error_code, headers=headers,
-                              response=json.dumps(response))
-
-
-class APIv2ValidationErrorMiddleware(ValidationErrorMiddleware):
-    def __init__(self, application):
-        super(APIv2ValidationErrorMiddleware, self).__init__(application)
-        self.api_version = 'API_v2'
-
-
-class SSLMiddleware(base.Middleware):
-    """A middleware that replaces the request wsgi.url_scheme environment
-    variable with the value of HTTP header configured in
-    secure_proxy_ssl_header if exists in the incoming request.
-    This is useful if the server is behind a SSL termination proxy.
-
-    Code nabbed from Heat.
-    """
-    # Replaced by oslo.middleware's http_proxy_to_wsgi middleware
-    @removals.remove
-    def __init__(self, application):
-        super(SSLMiddleware, self).__init__(application)
-        LOG.info('Starting designate ssl middleware')
-        self.secure_proxy_ssl_header = 'HTTP_{0}'.format(
-            cfg.CONF['service:api'].secure_proxy_ssl_header.upper().
-            replace('-', '_'))
-        self.override = cfg.CONF['service:api'].override_proto
-
-    def process_request(self, request):
-        request.environ['wsgi.url_scheme'] = request.environ.get(
-            self.secure_proxy_ssl_header, request.environ['wsgi.url_scheme'])
-        if self.override:
-            request.environ['wsgi.url_scheme'] = self.override
+                              response=jsonutils.dump_as_bytes(response))
