@@ -104,7 +104,7 @@ class BlacklistsController(rest.RestController):
         response = pecan.response
 
         if request.content_type == 'application/json-patch+json':
-            raise NotImplemented('json-patch not implemented')
+            raise NotImplementedError('json-patch not implemented')
 
         # Fetch the existing blacklist entry
         blacklist = self.central_api.get_blacklist(context, blacklist_id)
