@@ -29,7 +29,8 @@ CONF = cfg.CONF
 
 RESOURCE_STATUSES = ['ACTIVE', 'PENDING', 'DELETED', 'ERROR']
 RECORD_TYPES = ['A', 'AAAA', 'CNAME', 'MX', 'SRV', 'TXT', 'SPF', 'NS', 'PTR',
-                'SSHFP', 'SOA']
+                'SSHFP', 'SOA', 'NAPTR', 'CAA']
+
 TASK_STATUSES = ['ACTIVE', 'PENDING', 'DELETED', 'ERROR', 'COMPLETE']
 TSIG_ALGORITHMS = ['hmac-md5', 'hmac-sha1', 'hmac-sha224', 'hmac-sha256',
                    'hmac-sha384', 'hmac-sha512']
@@ -69,6 +70,8 @@ service_status = Table("service_statuses", metadata,
     Column('stats', types.JsonEncodedDict, nullable=False),
     Column('capabilities', types.JsonEncodedDict, nullable=False),
 
+    UniqueConstraint('service_name', 'hostname', name="unique_service_status"),
+
     mysql_engine='InnoDB',
     mysql_charset='utf8',
 )
