@@ -21,6 +21,7 @@ import oslo_messaging as messaging
 
 from designate import backend
 from designate import exceptions
+from designate import rpc
 from designate import service
 from designate import storage
 from designate.central import rpcapi as central_api
@@ -33,25 +34,45 @@ LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
-class Service(service.RPCService, service.Service):
+class AlsoNotifyTask(object):
+    """
+    Placeholder to define options for also_notify targets
+    """
+    pass
+
+
+class Service(service.RPCService):
     RPC_API_VERSION = '1.0'
 
     target = messaging.Target(version=RPC_API_VERSION)
 
+    def __init__(self):
+        self._central_api = None
+        self._storage = None
+
+        self._executor = None
+        self._pools_map = None
+
+        super(Service, self).__init__(
+            self.service_name, cfg.CONF['service:worker'].topic,
+            threads=cfg.CONF['service:worker'].threads,
+        )
+
     @property
     def central_api(self):
-        if not hasattr(self, '_central_api'):
+        if not self._central_api:
             self._central_api = central_api.CentralAPI.get_instance()
         return self._central_api
 
-    def _setup_target_backends(self, pool):
+    @staticmethod
+    def _setup_target_backends(pool):
         for target in pool.targets:
             # Fetch an instance of the Backend class
             target.backend = backend.get_backend(target)
 
         LOG.info('%d targets setup', len(pool.targets))
 
-        if len(pool.targets) == 0:
+        if not pool.targets:
             raise exceptions.NoPoolTargetsConfigured()
 
         return pool
@@ -85,25 +106,25 @@ class Service(service.RPCService, service.Service):
 
     @property
     def service_name(self):
-        return cfg.CONF['service:worker'].worker_topic
+        return 'worker'
 
     @property
     def storage(self):
-        if not hasattr(self, '_storage'):
+        if not self._storage:
             storage_driver = cfg.CONF['service:worker'].storage_driver
             self._storage = storage.get_storage(storage_driver)
         return self._storage
 
     @property
     def executor(self):
-        if not hasattr(self, '_executor'):
+        if not self._executor:
             # TODO(elarson): Create this based on config
             self._executor = processing.Executor()
         return self._executor
 
     @property
     def pools_map(self):
-        if not hasattr(self, '_pools_map'):
+        if self._pools_map is None:
             self._pools_map = {}
         return self._pools_map
 
@@ -117,13 +138,27 @@ class Service(service.RPCService, service.Service):
         super(Service, self).start()
         LOG.info('Started worker')
 
+    def stop(self, graceful=True):
+        super(Service, self).stop(graceful)
+
     def _do_zone_action(self, context, zone):
         pool = self.get_pool(zone.pool_id)
-        task = zonetasks.ZoneAction(
+        all_tasks = []
+        all_tasks.append(zonetasks.ZoneAction(
             self.executor, context, pool, zone, zone.action
-        )
-        return self.executor.run(task)
+        ))
 
+        # Send a NOTIFY to each also-notifies
+        for also_notify in pool.also_notifies:
+            notify_target = AlsoNotifyTask()
+            notify_target.options = {'host': also_notify.host,
+                                     'port': also_notify.port}
+            all_tasks.append(zonetasks.SendNotify(self.executor,
+                                                  zone,
+                                                  notify_target))
+        return self.executor.run(all_tasks)
+
+    @rpc.expected_exceptions()
     def create_zone(self, context, zone):
         """
         :param context: Security context information.
@@ -132,6 +167,7 @@ class Service(service.RPCService, service.Service):
         """
         self._do_zone_action(context, zone)
 
+    @rpc.expected_exceptions()
     def update_zone(self, context, zone):
         """
         :param context: Security context information.
@@ -140,6 +176,7 @@ class Service(service.RPCService, service.Service):
         """
         self._do_zone_action(context, zone)
 
+    @rpc.expected_exceptions()
     def delete_zone(self, context, zone):
         """
         :param context: Security context information.
@@ -148,6 +185,7 @@ class Service(service.RPCService, service.Service):
         """
         self._do_zone_action(context, zone)
 
+    @rpc.expected_exceptions()
     def recover_shard(self, context, begin, end):
         """
         :param begin: the beginning of the shards to recover
@@ -158,6 +196,7 @@ class Service(service.RPCService, service.Service):
             self.executor, context, begin, end
         ))
 
+    @rpc.expected_exceptions()
     def start_zone_export(self, context, zone, export):
         """
         :param zone: Zone to be exported
