@@ -40,12 +40,14 @@ from subprocess import check_output
 from subprocess import CalledProcessError
 from tempfile import NamedTemporaryFile
 from threading import Thread
-import json
 import logging
 import os
 import random
 import string
 import time
+import sys
+
+from oslo_serialization import jsonutils
 
 import dns
 import dns.resolver
@@ -59,10 +61,10 @@ designate_cli_path = '/usr/local/bin/designate'
 openstack_cli = 'openstack'
 
 
-def gen_random_name(l):
+def gen_random_name(length):
     return "".join(
         random.choice(string.ascii_lowercase + string.digits)
-        for n in range(l)
+        for n in range(length)
     )
 
 
@@ -116,13 +118,13 @@ class DesignateCLI(object):
         """Run a openstack client command using JSON output
 
         :returns: dict
-        :raises: CalledProcessError
+        :raises CalledProcessError:
         """
         cmd = "%s %s -f json" % (openstack_cli, cmd)
         log.debug("  running %s" % cmd)
         out = check_output(cmd, env=self._cli_env, shell=True,
                            executable='/bin/bash')
-        return json.loads(out)
+        return jsonutils.loads(out)
 
     def runcsv(self, cmd):
         """Run a command using the -f csv flag, parse the output
@@ -660,4 +662,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
